summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopetecontact.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:48:06 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:48:06 +0000
commit47c8a359c5276062c4bc17f0e82410f29081b502 (patch)
tree2d54a5f60a5b74067632f9ef6df58c2bc38155e6 /kopete/libkopete/kopetecontact.h
parent6f82532777a35e0e60bbd2b290b2e93e646f349b (diff)
downloadtdenetwork-47c8a359c5276062c4bc17f0e82410f29081b502.tar.gz
tdenetwork-47c8a359c5276062c4bc17f0e82410f29081b502.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1157648 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/libkopete/kopetecontact.h')
-rw-r--r--kopete/libkopete/kopetecontact.h76
1 files changed, 38 insertions, 38 deletions
diff --git a/kopete/libkopete/kopetecontact.h b/kopete/libkopete/kopetecontact.h
index 8f02bfc2..e093c5eb 100644
--- a/kopete/libkopete/kopetecontact.h
+++ b/kopete/libkopete/kopetecontact.h
@@ -20,7 +20,7 @@
#ifndef __KOPETECONTACT_H__
#define __KOPETECONTACT_H__
-#include <qobject.h>
+#include <tqobject.h>
#include <kurl.h>
#include <kdemacros.h>
#include "kopeteglobal.h"
@@ -41,7 +41,7 @@ class OnlineStatus;
class Plugin;
class Protocol;
class Account;
-typedef QPtrList<Group> GroupList;
+typedef TQPtrList<Group> GroupList;
/**
* @author Duncan Mac-Vicar P. <duncan@kde.org>
@@ -56,16 +56,16 @@ class KOPETE_EXPORT Contact : public QObject
Q_OBJECT
Q_ENUMS( CanCreateFlags )
- Q_PROPERTY( QString formattedName READ formattedName )
- Q_PROPERTY( QString formattedIdleTime READ formattedIdleTime )
+ Q_PROPERTY( TQString formattedName READ formattedName )
+ Q_PROPERTY( TQString formattedIdleTime READ formattedIdleTime )
Q_PROPERTY( bool isOnline READ isOnline )
Q_PROPERTY( bool fileCapable READ isFileCapable WRITE setFileCapable )
Q_PROPERTY( bool canAcceptFiles READ canAcceptFiles )
//Q_PROPERTY( bool isReachable READ isReachable )
- Q_PROPERTY( QString contactId READ contactId )
- Q_PROPERTY( QString icon READ icon WRITE setIcon )
- Q_PROPERTY( QString toolTip READ toolTip )
- Q_PROPERTY( QString nickName READ nickName WRITE setNickName )
+ Q_PROPERTY( TQString contactId READ contactId )
+ Q_PROPERTY( TQString icon READ icon WRITE setIcon )
+ Q_PROPERTY( TQString toolTip READ toolTip )
+ Q_PROPERTY( TQString nickName READ nickName WRITE setNickName )
//Q_PROPERTY( unsigned long idleTime READ idleTime WRITE setIdleTime )
public:
@@ -86,8 +86,8 @@ public:
* @param parent is the parent @ref MetaContact this Contact is part of
* @param icon is an optional icon
*/
- Contact( Account *account, const QString &id, MetaContact *parent,
- const QString &icon = QString::null );
+ Contact( Account *account, const TQString &id, MetaContact *parent,
+ const TQString &icon = TQString::null );
~Contact();
@@ -110,7 +110,7 @@ public:
*
* @return The unique id of the contact
*/
- QString contactId() const;
+ TQString contactId() const;
/**
* \brief Get the protocol that the contact belongs to.
@@ -172,17 +172,17 @@ public:
*
* Most plugins don't need more than these fields, so they only need
* to set the address book fields themselves. If you have nothing to
* save at all you can clear the QMap, an empty map is treated as
* 'nothing to save'.
*
* The provided addressBookFields QMap contains the index field as
* marked with @ref Plugin::addAddressBookField() with the
* contact id as value. If no index field is available the QMap is
* simply passed as an empty map.
*
* @sa Protocol::deserializeContact
*/
- virtual void serialize( QMap<QString, QString> &serializedData, QMap<QString, QString> &addressBookData );
+ virtual void serialize( TQMap<TQString, TQString> &serializedData, TQMap<TQString, TQString> &addressBookData );
/**
* @brief Serialize the contacts persistent properties for storage in the contact list.
@@ -192,12 +192,12 @@ public:
* In contrary to @ref serialize() this does not need to be reimplemented.
*
*/
- void serializeProperties(QMap<QString, QString> &serializedData);
+ void serializeProperties(TQMap<TQString, TQString> &serializedData);
/**
* @brief Deserialize the contacts persistent properties
*/
- void deserializeProperties(QMap<QString, QString> &serializedData);
+ void deserializeProperties(TQMap<TQString, TQString> &serializedData);
/**
* @brief Get the online status of the contact
@@ -222,12 +222,12 @@ public:
* @return Collection of menu items to be show on the context menu
* @todo if possible, try to use KXMLGUI
*/
- virtual QPtrList<KAction> *customContextMenuActions();
+ virtual TQPtrList<KAction> *customContextMenuActions();
/**
* @todo What is this function for ?
*/
- virtual QPtrList<KAction> *customContextMenuActions( ChatSession *manager );
+ virtual TQPtrList<KAction> *customContextMenuActions( ChatSession *manager );
/**
* @brief Get the Context Menu for this contact
@@ -288,7 +288,7 @@ public:
* If null, the protocol icon need to be used.
* The icon is not colored, nor has the status icon overloaded
*/
- QString& icon() const;
+ TQString& icon() const;
/**
* @brief Change the icon to use for this contact
@@ -298,7 +298,7 @@ public:
*
* if you want to go back to the protocol icon, set a null string.
*/
- void setIcon( const QString& icon );
+ void setIcon( const TQString& icon );
/**
* \brief Get the time (in seconds) this contact has been idle
@@ -322,25 +322,25 @@ public:
void setIdleTime(unsigned long int);
/**
* @return A QStringList containing all property keys
**/
- QStringList properties() const;
+ TQStringList properties() const;
/**
* Check for existance of a certain property stored
* using "key".
* \param key the property to check for
**/
- bool hasProperty(const QString &key) const;
+ bool hasProperty(const TQString &key) const;
/**
* \brief Get the value of a property with key "key".
*
* If you don't know the type of the returned QVariant, you will need
* to check for it.
* \return the value of the property
**/
- const Kopete::ContactProperty &property(const QString &key) const;
+ const Kopete::ContactProperty &property(const TQString &key) const;
const Kopete::ContactProperty &property(const Kopete::ContactPropertyTmpl &tmpl) const;
/**
@@ -350,27 +350,27 @@ public:
* taken from this one
* @param value The value to store
*
* \note Setting a NULL value or an empty QString castable value
* removes the property if it already existed.
* <b>Don't</b> abuse this for property-removal, instead use
* @ref removeProperty() if you want to remove on purpose.
* The Removal is done to clean up the list of properties and to purge them
* from UI.
**/
- void setProperty(const Kopete::ContactPropertyTmpl &tmpl, const QVariant &value);
+ void setProperty(const Kopete::ContactPropertyTmpl &tmpl, const TQVariant &value);
/**
* \brief Convenience method to set the nickName property to the specified value
* @param name The nickname to set
*/
- void setNickName( const QString &name );
+ void setNickName( const TQString &name );
/**
* \brief Convenience method to retrieve the nickName property.
*
* This method will return the contactId if there has been no nickName property set
*/
- QString nickName() const;
+ TQString nickName() const;
/**
* \brief Remove a property if it exists
@@ -384,20 +384,20 @@ public:
* Makes use of formattedName() and formattedIdleTime().
* \return an RTF tooltip depending on KopetePrefs settings
**/
- QString toolTip() const;
+ TQString toolTip() const;
/**
* Returns a formatted string of "firstName" and/or "lastName" properties
* if present.
* Suitable for GUI display
**/
- QString formattedName() const;
+ TQString formattedName() const;
/**
* Returns a formatted string of idleTime().
* Suitable for GUI display
**/
- QString formattedIdleTime() const;
+ TQString formattedIdleTime() const;
/**
* used in @ref sync()
@@ -475,7 +475,7 @@ public slots:
* file size (such as over asocket
*/
virtual void sendFile( const KURL &sourceURL = KURL(),
- const QString &fileName = QString::null, uint fileSize = 0L );
+ const TQString &fileName = TQString::null, uint fileSize = 0L );
private slots:
@@ -532,11 +532,11 @@ signals:
* One of the contact's properties has changed.
* @param contact this contact, useful for listening to signals from more than one contact
* @param key the key whose value has changed
* @param oldValue the value before the change, or an invalid QVariant if the property is new
* @param newValue the value after the change, or an invalid QVariant if the property was removed
*/
- void propertyChanged( Kopete::Contact *contact, const QString &key,
- const QVariant &oldValue, const QVariant &newValue );
+ void propertyChanged( Kopete::Contact *contact, const TQString &key,
+ const TQVariant &oldValue, const TQVariant &newValue );
protected:
virtual void virtual_hook(uint id, void *data);
@@ -172,17 +172,17 @@ public:
* Most plugins don't need more than these fields, so they only need
* to set the address book fields themselves. If you have nothing to
- * save at all you can clear the QMap, an empty map is treated as
+ * save at all you can clear the TQMap, an empty map is treated as
* 'nothing to save'.
*
@@ -172,17 +172,17 @@ public:
* 'nothing to save'.
*
- * The provided addressBookFields QMap contains the index field as
+ * The provided addressBookFields TQMap contains the index field as
* marked with @ref Plugin::addAddressBookField() with the
@@ -172,17 +172,17 @@ public:
* marked with @ref Plugin::addAddressBookField() with the
- * contact id as value. If no index field is available the QMap is
+ * contact id as value. If no index field is available the TQMap is
* simply passed as an empty map.
*
@@ -322,25 +322,25 @@ public:
void setIdleTime(unsigned long int);
/**
- * @return A QStringList containing all property keys
+ * @return A TQStringList containing all property keys
**/
@@ -322,25 +322,25 @@ public:
* \brief Get the value of a property with key "key".
*
- * If you don't know the type of the returned QVariant, you will need
+ * If you don't know the type of the returned TQVariant, you will need
* to check for it.
* \return the value of the property
@@ -350,27 +350,27 @@ public:
* @param value The value to store
*
- * \note Setting a NULL value or an empty QString castable value
+ * \note Setting a NULL value or an empty TQString castable value
* removes the property if it already existed.
* <b>Don't</b> abuse this for property-removal, instead use
@@ -532,11 +532,11 @@ signals:
* @param contact this contact, useful for listening to signals from more than one contact
* @param key the key whose value has changed
- * @param oldValue the value before the change, or an invalid QVariant if the property is new
- * @param newValue the value after the change, or an invalid QVariant if the property was removed
+ * @param oldValue the value before the change, or an invalid TQVariant if the property is new
+ * @param newValue the value after the change, or an invalid TQVariant if the property was removed
*/